OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Não é possível gravar no diretório \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Isso geralmente pode ser corrigido dando o acesso de gravação ao webserver para o diretório de configuração",
    "See %s" : "Ver %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Isso geralmente pode ser corrigido dando permissão de gravação %sgiving ao webserver para o directory%s de configuração.",
    "Sample configuration detected" : "Exemplo de configuração detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração exemplo foi copiada. Isso pode desestabilizar sua instalação e não é suportado. Por favor, leia a documentação antes de realizar mudanças no config.php",
    "PHP %s or higher is required." : "É requerido PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "É requerida uma versão PHP mais antiga que a %s .",
    "%sbit or higher PHP required." : "%sbit ou maior é requerido.",
    "Following databases are supported: %s" : "Following databases are supported: %s",
    "The command line tool %s could not be found" : "A ferramenta de linha de comando %s não pode ser encontrada",
    "The library %s is not available." : "A biblioteca %s não está disponível.",
    "Library %s with a version higher than %s is required - available version %s." : "É requerida uma biblioteca %s com uma versão maior que %s - versão disponível %s.",
    "Library %s with a version lower than %s is required - available version %s." : "É requerida uma biblioteca %s com uma versão menor que %s - versão disponível %s.",
    "Following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
    "ownCloud %s or higher is required." : "É necessário um ownCloud %s ou superior.",
    "ownCloud %s or lower is required." : "É necessário um ownCloud %s ou inferior.",
    "Unknown filetype" : "Tipo de arquivo desconhecido",
    "Invalid image" : "Imagem inválida",
    "Avatar image is not square" : "A imagem avatar não é quadrada",
    "today" : "hoje",
    "yesterday" : "ontem",
    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás"],
    "last month" : "último mês",
    "_%n month ago_::_%n months ago_" : ["há %n mês atrás","há %n meses atrás"],
    "last year" : "último ano",
    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás"],
    "_%n hour ago_::_%n hours ago_" : ["há %n hora atrás","há %n horas atrás"],
    "_%n minute ago_::_%n minutes ago_" : ["há %n minuto atrás","há %n minutos atrás"],
    "seconds ago" : "segundos atrás",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Módulo com id: %s não existe. Ative-o em suas configurações de aplicativos ou contate o administrador.",
    "Builtin" : "Construídas em",
    "None" : "Nenhum",
    "Username and password" : "Nome de Usuário e senha",
    "Username" : "Nome do Usuário",
    "Password" : "Senha",
    "Log-in credentials, save in session" : "Credenciais de login, guardados em sessão",
    "Empty filename is not allowed" : "Um nome de arquivo vazio não é permitido.",
    "Dot files are not allowed" : "Dot arquivos não são permitidos",
    "4-byte characters are not supported in file names" : "Caracteres de 4-bytes não são suportados em nomes de arquivos",
    "File name is a reserved word" : "O nome do arquivo é uma palavra reservada",
    "File name contains at least one invalid character" : "O nome do arquivo contém pelo menos um caractere inválido",
    "File name is too long" : "O nome do arquivo é muito longo",
    "__language_name__" : "__language_name__",
    "App directory already exists" : "Diretório App  já existe",
    "Can't create app folder. Please fix permissions. %s" : "Não é possível criar pasta app. Corrija as permissões. %s",
    "Archive does not contain a directory named %s" : "O arquivo não contém um diretório chamado %s",
    "No source specified when installing app" : "Nenhuma fonte foi especificada enquanto instalava o aplicativo",
    "No href specified when installing app from http" : "Nenhuma href foi especificada enquanto instalava o aplicativo de http",
    "No path specified when installing app from local file" : "Nenhum caminho foi especificado enquanto instalava o aplicativo do arquivo local",
    "Archives of type %s are not supported" : "Arquivos do tipo %s não são suportados",
    "Failed to open archive when installing app" : "Falha para abrir o arquivo enquanto instalava o aplicativo",
    "App does not provide an info.xml file" : "O aplicativo não fornece um arquivo info.xml",
    "App cannot be installed because appinfo file cannot be read." : "O App não pode ser instalado porque o arquivo appinfo não pode ser lido.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "A assinatura não pode ser verificada. Por favor entre em contato com o desenvolvedor do aplicativo e verificar sua tela de administração.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "O aplicativo não pode ser instalado porque não é compatível com esta versão do ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "O aplicativo não pode ser instalado porque ele contém a marca <shipped>verdadeiro</shipped> que não é permitido para aplicações não embarcadas",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "O aplicativo não pode ser instalado porque a versão em info.xml não é o mesmo que a versão relatada na App Store",
    "No license key available." : "Nenhuma chave de licença disponível.",
    "Invalid license key!" : "Chave de licença inválida!",
    "Please contact your administrator or %s for a new license key." : "Entre em contato com seu administrador %s para uma nova chave de licença.",
    "Your Enterprise license key has expired." : "Sua chave de licença corporativa expirou.",
    "Enterprise features have been disabled." : "Os recursos da empresa foram desativados.",
    "Evaluation - expires in %d days." : "Avaliação - expira em %d dias.",
    "Your Enterprise license key is about to expire (days remaining: %d)." : "Sua chave de licença Enterprise está prestes a expirar (dias restantes: %d).",
    "The registered enterprise license key expires in %d days" : "A chave de licença corporativa registrada expira em %d dias",
    "New Design" : "Novo Design",
    "Apps" : "Aplicações",
    "General" : "Geral",
    "Storage" : "Armazenamento",
    "Security" : "Segurança",
    "User Authentication" : "Autenticação de Usuário",
    "Encryption" : "Criptografia",
    "Workflows & Tags" : "Fluxos de Trabalho & Etiquetas",
    "Sharing" : "Compartilhamento",
    "Search" : "Pesquisar",
    "Help & Tips" : "Ajuda & Dicas",
    "Additional" : "Adicional",
    "%s enter the database username and name." : "%s insira o nome de usuário e o nome do banco de dados.",
    "%s enter the database username." : "%s insira o nome de usuário do banco de dados.",
    "%s enter the database name." : "%s insira o nome do banco de dados.",
    "%s enter the database name or connection string." : "%s insira o nome do banco de dados ou a string de conexão.",
    "Oracle connection could not be established" : "Conexão Oracle não pode ser estabelecida",
    "Oracle username and/or password not valid" : "Nome de usuário e/ou senha Oracle inválido(s)",
    "DB Error: \"%s\"" : "Erro no BD: \"%s\"",
    "Offending command was: \"%s\"" : "Comando ofensivo era: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Você precisa inserir uma conta existente ou a do administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Comando ofensivo era: \"%s\", nome: %s, senha: %s",
    "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválido(s)",
    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco. ",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obter os melhores resultados, por favor, considere o uso de um servidor GNU/Linux em seu lugar.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32bit e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente desencorajado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou altere o PHP para 64bit.",
    "Set an admin username." : "Defina um nome do usuário administrador.",
    "Set an admin password." : "Defina uma senha de administrador.",
    "Can't create or write into the data directory %s" : "Não é possível criar ou gravar no diretório de dados %s",
    "Can't create or write into the apps-external directory %s" : "Não é possível criar ou gravar no diretório apps-external %s",
    "Can't update %s - it is a directory" : "Não é possível atualizar %s - isto é um diretório",
    "Can't update %s" : "Não consigo atualizar %s",
    "Invalid Federated Cloud ID" : "Associação Inválida de Nuvem ID",
    "Internal mail notification for shared files is not allowed" : "Notificação de correio interno para arquivos compartilhados não é permitida",
    "%s shared »%s« with you" : "%s compartilhou »%s« com você",
    "Public link mail notification is not allowed" : "Notificação de correio de linque público não é permitida",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %d" : "O compartilhamento de %s falhou porque o back-end não permite compartilhamentos do tipo %d",
    "Sharing %s failed, because the file does not exist" : "Compartilhamento %s falhou, porque o arquivo não existe",
    "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
    "Sharing %s failed, because you can not share with yourself" : "O compartilhamento %s falhou, porque você não pode compartilhar com você mesmo",
    "Sharing %s failed, because the user %s does not exist" : "Compartilhamento %s falhou, porque o usuário %s não existe",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Compartilhamento %s falhou, porque o usuário %s não é membro de nenhum grupo que o usuário %s pertença",
    "Sharing %s failed, because this item is already shared with %s" : "Compartilhamento %s falhou, porque este ítem já está compartilhado com %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Compartilhamento de %s falhou, porque esse item já é compartilhada com o usuário %s",
    "Sharing %s failed, because the group %s does not exist" : "Compartilhamento %s falhou, porque o grupo %s não existe",
    "Sharing %s failed, because %s is not a member of the group %s" : "Compartilhamento %s falhou, porque  %s não é membro do grupo %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Você precisa fornecer uma senha para criar um link público, apenas links protegidos são permitidos",
    "Sharing %s failed, because sharing with links is not allowed" : "Compartilhamento %s falhou, porque compartilhamento com links não é permitido",
    "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento associado com o mesmo usuário",
    "Sharing %s failed, could not find %s, check spelling and server availability." : "O compartilhamento  %s falhou, não foi possível encontrar %s, verifique o que foi digitado e a disponibilidade do servidor.",
    "Share type %s is not valid for %s" : "Tipo de compartilhamento %s não é válido para %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Definir permissões para %s falhou, porque as permissões excedem as permissões concedidas a %s",
    "Setting permissions for %s failed, because the item was not found" : "Definir permissões para %s falhou, porque o item não foi encontrado",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Não é possível definir a data de expiração. Compartilhamentos não podem expirar mais tarde que %s depois de terem sido compartilhados",
    "Cannot set expiration date. Expiration date is in the past" : "Não é possível definir a data de validade. Data de expiração está no passado",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Não é possível eliminar a data de expiração. Ações são obrigados a ter uma data de expiração.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Compartilhando backend %s deve implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Compartilhamento backend %s não encontrado",
    "Sharing backend for %s not found" : "Compartilhamento backend para %s não encontrado",
    "Sharing failed, because the user %s is the original sharer" : "O compartilhamento falhou, porque o usuário %s é o compartilhador original",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Compartilhamento %s falhou, porque as permissões excedem as permissões concedidas a %s",
    "Sharing %s failed, because resharing is not allowed" : "Compartilhamento %s falhou, porque recompartilhamentos não são permitidos",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Compartilhamento %s falhou, porque a infra-estrutura de compartilhamento para %s não conseguiu encontrar a sua fonte",
    "Sharing %s failed, because the file could not be found in the file cache" : "Compartilhamento %s falhou, porque o arquivo não pôde ser encontrado no cache de arquivos",
    "Invalid permissions" : "Permissões inválidas",
    "Cannot remove all permissions" : "Não é possível remover todas as permissões",
    "Cannot set the requested share permissions for %s" : "Não é possível definir as permissões de compartilhamento solicitadas para %s",
    "Cannot set the requested share attributes for %s" : "Não é possível definir os atributos de compartilhamento solicitados para %s",
    "Expiration date is in the past" : "Data de validade está ultrapassada",
    "Cannot set expiration date more than %s days in the future" : "Não é possível definir a data de validade mais de %s dias no futuro",
    "Could not find category \"%s\"" : "Impossível localizar categoria \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"",
    "A valid username must be provided" : "Forneça um nome de usuário válido",
    "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
    "The username must be at least 3 characters long" : "O nome de usuário deve ter pelo menos 3 caracteres",
    "The username can not be longer than 64 characters" : "O nome de usuário não pode ter mais de 64 caracteres",
    "A valid password must be provided" : "Forneça uma senha válida",
    "The username is already being used" : "Este nome de usuário já está sendo usado",
    "Login canceled by app" : "Login cancelado pelo aplicativo",
    "User disabled" : "Usuário desativado",
    "Settings" : "Configurações",
    "Users" : "Usuários",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" não pode ser instalado porque as seguintes dependências não foram cumpridas: %s",
    "A safe home for all your data" : "Um lugar seguro para todos os seus dados",
    "Imprint" : "Imprimir",
    "Privacy Policy" : "Política de Privacidade",
    "File is currently busy, please try again later" : "O arquivo está ocupado, tente novamente mais tarde",
    "Access to this resource or one of its sub-items has been denied." : "O acesso a este recurso ou a um dos seus subitens foi negado.",
    "File cannot be downloaded" : "Não é possível baixar o arquivo",
    "Application is not enabled" : "Aplicação não está habilitada",
    "Authentication error" : "Erro de autenticação",
    "Token expired. Please reload page." : "Token expirou. Por favor recarregue a página.",
    "Unknown user" : "Usuário desconhecido",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhum driver  de banco de dados (sqlite, mysql, or postgresql) instalado.",
    "Cannot write into \"config\" directory" : "Não é possível gravar no diretório \"config\"",
    "Cannot create \"data\" directory" : "Não é possível criar o diretório \"data\"",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Esta geralmente pode ser fixado por <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dando permissão de gravação ao diretório raiz do servidor</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Permissões podem ser corrigidas dando permissão de escita %sgiving ao webserver para o diretório raiz directory%s",
    "Setting locale to %s failed" : "Falha ao configurar localidade para %s",
    "Please install one of these locales on your system and restart your webserver." : "Por favor, defina uma dessas localizações em seu sistema e reinicie o seu servidor web.",
    "Please ask your server administrator to install the module." : "Por favor, peça ao seu administrador do servidor para instalar o módulo.",
    "PHP module %s not installed." : "Módulo PHP %s não instalado.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Configurações \"%s\" PHP não está configurado para \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Ajustando esta configuração no php.ini irá fazer o ownCloud rodar novamente",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está definido para \"%s\" em vez do valor esperado \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corrigir esse problema defina <code>mbstring.func_overload</code> para <code>0</code> em seu php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "A libxml2 2.7.0 é a mínima versão requerida. Atualmente a versão %s está instalada.",
    "To fix this issue update your libxml2 version and restart your web server." : "Para corrigir este problema, atualize a versão da sua libxml2 e reinicie seu servidor web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está, aparentemente, configurado para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por uma cache/acelerador, como Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Módulos do PHP foram instalados, mas eles ainda estão listados como desaparecidos?",
    "Please ask your server administrator to restart the web server." : "Por favor, peça ao seu administrador do servidor para reiniciar o servidor web.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requirido",
    "Please upgrade your database version" : "Por favor, atualize sua versão do banco de dados",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor, altere as permissões para 0770 para que o diretório não possa ser listado por outros usuários.",
    "Your Data directory is readable by other users" : "Seu diretório de Dados é legível por outros usuários",
    "Your Data directory must be an absolute path" : "Seu diretório de Dados deve ser um caminho absoluto",
    "Check the value of \"datadirectory\" in your configuration" : "Verifique o valor do \"diretóriodedados\" na sua configuração",
    "Your Data directory  is invalid" : "Seu diretório de Dados é inválido",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Por favor, verifique se o diretório de dados contém um arquivo \".ocdata\" em sua raiz.",
    "User unknown" : "Usuário desconhecido",
    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter tipo de bloqueio %d em \"%s\".",
    "Storage unauthorized. %s" : "Armazenamento não autorizado. %s",
    "Storage incomplete configuration. %s" : "Incompleta configuração de armazenamento. %s",
    "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
    "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
    "Storage connection timeout. %s" : "Tempo limite de conexão de armazenamento. %s",
    "\"%s\" is locked" : "\"%s\" está bloqueado"
},
"nplurals=2; plural=(n > 1);");
